==> skaffold-2.0.3.tar.gz: skaffold-2.0.3/pkg/diag/validator/custom_resource.go <==
/*
Copyright 2021 The Skaffold Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package validator

import (
	"context"
	"fmt"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
	"k8s.io/apimachinery/pkg/runtime/schema"
	"k8s.io/client-go/dynamic"
	"k8s.io/client-go/kubernetes"

	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/util"
)

type CustomResourceSelector struct {
	client    kubernetes.Interface
	dynClient dynamic.Interface
	kind      schema.GroupVersionKind
}

func NewCustomResourceSelector(client kubernetes.Interface, dynClient dynamic.Interface, gvk schema.GroupVersionKind) *CustomResourceSelector {
	return &CustomResourceSelector{client: client, dynClient: dynClient, kind: gvk}
}

// Select returns the updated list of custom resources for the given GroupVersionKind deployed by skaffold
func (c *CustomResourceSelector) Select(ctx context.Context, namespace string, opts metav1.ListOptions) (*unstructured.UnstructuredList, error) {
	_, r, err := util.GroupVersionResource(c.client.Discovery(), c.kind)
	if err != nil {
		return nil, fmt.Errorf("listing resources of kind %v: %w", c.kind, err)
	}
	resList, err := c.dynClient.Resource(r).Namespace(namespace).List(ctx, opts)
	if err != nil {
		return nil, fmt.Errorf("listing resources of kind %v: %w", c.kind, err)
	}
	return resList, nil
}

==> skaffold-2.3.0.tar.gz: skaffold-2.3.0/pkg/diag/validator/custom_resource.go <==
/*
Copyright 2021 The Skaffold Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package validator

import (
	"context"
	"fmt"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
	"k8s.io/apimachinery/pkg/runtime/schema"
	"k8s.io/client-go/dynamic"
	"k8s.io/client-go/kubernetes"

	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/deploy/util"
)

type CustomResourceSelector struct {
	client    kubernetes.Interface
	dynClient dynamic.Interface
	kind      schema.GroupVersionKind
}

func NewCustomResourceSelector(client kubernetes.Interface, dynClient dynamic.Interface, gvk schema.GroupVersionKind) *CustomResourceSelector {
	return &CustomResourceSelector{client: client, dynClient: dynClient, kind: gvk}
}

// Select returns the updated list of custom resources for the given GroupVersionKind deployed by skaffold
func (c *CustomResourceSelector) Select(ctx context.Context, namespace string, opts metav1.ListOptions) (*unstructured.UnstructuredList, error) {
	_, r, err := util.GroupVersionResource(c.client.Discovery(), c.kind)
	if err != nil {
		return nil, fmt.Errorf("listing resources of kind %v: %w", c.kind, err)
	}
	resList, err := c.dynClient.Resource(r).Namespace(namespace).List(ctx, opts)
	if err != nil {
		return nil, fmt.Errorf("listing resources of kind %v: %w", c.kind, err)
	}
	return resList, nil
}
